Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/image/README.txt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/image/README.txt	(revision 11945)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/image/README.txt	(revision 11949)
@@ -1,9 +1,9 @@
-waeup.kofa.image -- handling image files
+waeup.ikoba.image -- handling image files
 ========================================
 
-The image file widget is built on top of the :class:`KofaImageFile` object::
-
-  >>> from waeup.kofa.image import KofaImageFile
-  >>> file = KofaImageFile('foo.jpg', 'mydata')
+The image file widget is built on top of the :class:`IkobaImageFile` object::
+
+  >>> from waeup.ikoba.image import IkobaImageFile
+  >>> file = IkobaImageFile('foo.jpg', 'mydata')
   >>> file.filename
   'foo.jpg'
@@ -16,5 +16,5 @@
   'mydata'
 
-We can also create KofaImageFile objects from file-like objects::
+We can also create IkobaImageFile objects from file-like objects::
 
   >>> from StringIO import StringIO
@@ -36,5 +36,5 @@
 ----------------
 
-The KofaImageFile object normally stores the file data using ZODB
+The IkobaImageFile object normally stores the file data using ZODB
 persistence. Files can however also be stored by tramline.  If
 tramline is installed in Apache, the Tramline takes care of generating
@@ -73,5 +73,5 @@
 just '1') will now be created::
 
-  >>> file = KofaImageFile('foo.jpg', '1')
+  >>> file = IkobaImageFile('foo.jpg', '1')
 
 The data is now '1', referring to the real file::
@@ -102,5 +102,5 @@
 We expect the same behavior as when tramline is not installed::
 
-  >>> file = KofaImageFile('foo.jpg', 'data')
+  >>> file = IkobaImageFile('foo.jpg', 'data')
   >>> f = file.file
   >>> f.read()
@@ -114,11 +114,11 @@
   >>> shutil.rmtree(dirpath)
 
-Support for :mod:`waeup.kofa.imagestorage`
+Support for :mod:`waeup.ikoba.imagestorage`
 ------------------------------------------
 
 The behaviour shown above can be used for any Zope3 application. With
-:mod:`waeup.kofa` we use a special file retrieval utility defined in
-:mod:`waeup.kofa.imagestorage`. As this utility is based on
-:mod:`waeup.kofa` internal stuff we do not show it here but in the
+:mod:`waeup.ikoba` we use a special file retrieval utility defined in
+:mod:`waeup.ikoba.imagestorage`. As this utility is based on
+:mod:`waeup.ikoba` internal stuff we do not show it here but in the
 tests that come with that storage type.
 
@@ -135,5 +135,5 @@
 The `ImageFile` field accepts only certain content types:
 
-  >>> from waeup.kofa.image.schema import ImageFile
+  >>> from waeup.ikoba.image.schema import ImageFile
   >>> from zope.publisher.browser import TestRequest
   >>> field = ImageFile(__name__='foo', title=u'Foo')
@@ -141,12 +141,12 @@
   Traceback (most recent call last):
   ...
-  WrongType: ('asd', <class 'waeup.kofa.image.image.KofaImageFile'>, 'foo')
+  WrongType: ('asd', <class 'waeup.ikoba.image.image.IkobaImageFile'>, 'foo')
 
 which means: `ImageFile` fields should better contain
-:class:`KofaImageFile` instances.
-
-We can store normal :class:`KofaImageFile` instances:
-
-  >>> field.validate(KofaImageFile('bar.jpg', 'data')) is None
+:class:`IkobaImageFile` instances.
+
+We can store normal :class:`IkobaImageFile` instances:
+
+  >>> field.validate(IkobaImageFile('bar.jpg', 'data')) is None
   True
 
@@ -173,9 +173,9 @@
 
   >>> field.validate(
-  ...     KofaImageFile('bar.jpg', '123456789012')) is None
-  True
-
-  >>> field.validate(
-  ...     KofaImageFile('bar.jpg', '12345')) is None
+  ...     IkobaImageFile('bar.jpg', '123456789012')) is None
+  True
+
+  >>> field.validate(
+  ...     IkobaImageFile('bar.jpg', '12345')) is None
   True
 
@@ -183,5 +183,5 @@
 
   >>> field.validate(
-  ...     KofaImageFile('bar.jpg', '1234567890123'))
+  ...     IkobaImageFile('bar.jpg', '1234567890123'))
   Traceback (most recent call last):
   ...
@@ -189,5 +189,5 @@
 
   >>> field.validate(
-  ...     KofaImageFile('bar.jpg', '1234'))
+  ...     IkobaImageFile('bar.jpg', '1234'))
   Traceback (most recent call last):
   ...
@@ -198,10 +198,10 @@
 ----------------------------
 
-KofaImageFile does not reproduce the broken unequal comparison from
+IkobaImageFile does not reproduce the broken unequal comparison from
 its base:
 
-  >>> f1 = KofaImageFile('bar.jpg', '123456789')
-  >>> f2 = KofaImageFile('bar.jpg', '123456789')
-  >>> f3 = KofaImageFile('baz.jpg', '1234')
+  >>> f1 = IkobaImageFile('bar.jpg', '123456789')
+  >>> f2 = IkobaImageFile('bar.jpg', '123456789')
+  >>> f3 = IkobaImageFile('baz.jpg', '1234')
   >>> f1 == f2
   True
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/image/__init__.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/image/__init__.py	(revision 11945)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/image/__init__.py	(revision 11949)
@@ -3,8 +3,8 @@
 Including schemas, widgets and the content components.
 """
-from waeup.kofa.image.image import KofaImageFile, createKofaImageFile
+from waeup.ikoba.image.image import IkobaImageFile, createIkobaImageFile
 
 __all__ = [
-    "KofaImageFile",
-    "createKofaImageFile",
+    "IkobaImageFile",
+    "createIkobaImageFile",
     ]
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/image/browser/__init__.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/image/browser/__init__.py	(revision 11945)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/image/browser/__init__.py	(revision 11949)
@@ -1,5 +1,5 @@
 # The public API part
 # Contains the widgets defined for image files.
-from waeup.kofa.image.browser.widget import (
+from waeup.ikoba.image.browser.widget import (
     EncodingImageFileWidget, ThumbnailWidget,
     )
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/image/browser/tests/image.txt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/image/browser/tests/image.txt	(revision 11945)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/image/browser/tests/image.txt	(revision 11949)
@@ -12,8 +12,8 @@
 
   >>> import os
-  >>> from waeup.kofa.image import KofaImageFile
+  >>> from waeup.ikoba.image import IkobaImageFile
   >>> testimage = os.path.join(os.path.dirname(__file__), 'sample.jpg')
   >>> testimage2 = os.path.join(os.path.dirname(__file__), 'sample2.jpg')
-  >>> some_file = KofaImageFile('foo.jpg', open(testimage, 'rb').read())
+  >>> some_file = IkobaImageFile('foo.jpg', open(testimage, 'rb').read())
   >>> some_file.filename
   'foo.jpg'
@@ -26,5 +26,5 @@
   >>> from hurry.file.browser import DownloadWidget
   >>> from hurry.file.schema import File
-  >>> from waeup.kofa.image.schema import ImageFile
+  >>> from waeup.ikoba.image.schema import ImageFile
   >>> from zope.publisher.browser import TestRequest
   >>> field = ImageFile(__name__='foo', title=u'Foo')
@@ -51,5 +51,5 @@
 Instead of downloading, we can also use a thumbnail widget:
 
-  >>> from waeup.kofa.image.browser import ThumbnailWidget
+  >>> from waeup.ikoba.image.browser import ThumbnailWidget
   >>> request = TestRequest(form={'field.foo': FileUpload(some_file)})
   >>> widget = ThumbnailWidget(field, request)
@@ -61,5 +61,5 @@
 data already available, and no data in request:
 
-  >>> from waeup.kofa.image.browser import EncodingImageFileWidget
+  >>> from waeup.ikoba.image.browser import EncodingImageFileWidget
   >>> field = ImageFile(__name__='foo', title=u'Foo', required=False)
   >>> field = field.bind(None)
@@ -166,5 +166,5 @@
 prepare some new file:
 
-  >>> another_file = KofaImageFile('bar.txt', 'bar contents')
+  >>> another_file = IkobaImageFile('bar.txt', 'bar contents')
 
 We happen to know, due to the implementation of
@@ -200,5 +200,5 @@
 ---------------------------
 
-As :class:`waeup.kofa.image.KofaImageFile` objects support storing
+As :class:`waeup.ikoba.image.IkobaImageFile` objects support storing
 image data by using external 'storages', also our widgets should do
 so.
@@ -220,5 +220,5 @@
   ...         contents = f.read()
   ...         id_string = hashlib.md5(contents).hexdigest()
-  ...         result = KofaImageFile(filename, id_string)
+  ...         result = IkobaImageFile(filename, id_string)
   ...         self.storage[id_string] = contents
   ...         return result
@@ -260,9 +260,9 @@
 We now want to simulate, that the field contains already data,
 identified by some `file_id`. To do so, we first store the data in our
-file retrieval and then create a KofaImageFile object with that
+file retrieval and then create a IkobaImageFile object with that
 file_id stored:
 
-  >>> from waeup.kofa.image import createKofaImageFile
-  >>> image = createKofaImageFile(
+  >>> from waeup.ikoba.image import createIkobaImageFile
+  >>> image = createIkobaImageFile(
   ...     'sample.jpg', open(testimage, 'rb'))
   >>> file_id = image.data
@@ -274,5 +274,5 @@
   '9feac4265077922000aa8b88748e25be'
 
-The new file was stored by our utility, as createKofaImageFile looks
+The new file was stored by our utility, as createIkobaImageFile looks
 up IFileRetrieval utilities and uses them:
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/image/browser/tests/test_views.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/image/browser/tests/test_views.py	(revision 11945)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/image/browser/tests/test_views.py	(revision 11949)
@@ -30,5 +30,5 @@
 from hurry.file.file import IdFileRetrieval
 from hurry.file.interfaces import IFileRetrieval
-from waeup.kofa.image.browser.views import HurryFileView
+from waeup.ikoba.image.browser.views import HurryFileView
 from zope.component import getMultiAdapter, provideUtility
 from zope.publisher.browser import TestRequest
@@ -41,9 +41,9 @@
 class ImageBrowserViewsLayer(object):
     """A layer that registers all components in
-       `waeup.kofa.image.browser.views` module.
+       `waeup.ikoba.image.browser.views` module.
     """
     @classmethod
     def setUp(cls):
-        grok.testing.grok('waeup.kofa.image.browser.views')
+        grok.testing.grok('waeup.ikoba.image.browser.views')
 
     @classmethod
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/image/browser/widget.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/image/browser/widget.py	(revision 11945)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/image/browser/widget.py	(revision 11949)
@@ -19,5 +19,5 @@
 """
 import os
-from waeup.kofa.image import KofaImageFile
+from waeup.ikoba.image import IkobaImageFile
 from hurry.file.browser.widget import (
     EncodingFileWidget, DownloadWidget, FakeFieldStorage)
@@ -62,5 +62,5 @@
                 seek(0)
                 return retrieval.createFile(input.filename, input)
-            return KofaImageFile(input.filename, data)
+            return IkobaImageFile(input.filename, data)
         else:
             return self.context.missing_value
@@ -143,5 +143,5 @@
         data = file_id.decode('base64')
         filename, filedata = data.split('\n', 1)
-        return KofaImageFile(filename, filedata)
+        return IkobaImageFile(filename, filedata)
 
 class ThumbnailWidget(DownloadWidget):
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/image/interfaces.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/image/interfaces.py	(revision 11945)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/image/interfaces.py	(revision 11949)
@@ -16,5 +16,5 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-"""Interfaces for waeup.kofa.image
+"""Interfaces for waeup.ikoba.image
 """
 from hurry.file.interfaces import IFile, IFileRetrieval, IHurryFile
@@ -24,5 +24,5 @@
     """
 
-class IKofaImageFile(IHurryFile):
+class IIkobaImageFile(IHurryFile):
     """Image file.
     """
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/image/schema.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/image/schema.py	(revision 11945)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/image/schema.py	(revision 11949)
@@ -22,6 +22,6 @@
 from zope.schema.interfaces import TooBig, TooSmall
 from hurry.file.schema import File
-from waeup.kofa.image.interfaces import IImageFile
-from waeup.kofa.image.image import KofaImageFile
+from waeup.ikoba.image.interfaces import IImageFile
+from waeup.ikoba.image.image import IkobaImageFile
 
 class MinMaxSize(object):
@@ -82,3 +82,3 @@
     implements(IImageFile)
 
-    _type = KofaImageFile
+    _type = IkobaImageFile

Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/image/image.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/image/image.py	(revision 11945)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/image/image.py	(revision 11949)
@@ -23,7 +23,7 @@
 from zope.component import getUtility
 from zope.interface import implements
-from waeup.kofa.image.interfaces import IKofaImageFile
+from waeup.ikoba.image.interfaces import IIkobaImageFile
 
-class KofaImageFile(HurryFile):
+class IkobaImageFile(HurryFile):
     """A file prepared for storing image files.
 
@@ -32,8 +32,8 @@
     regular hurry files.
 
-    To create a :class:`KofaImageFile` you should use
-    :func:`createKofaImageFile`.
+    To create a :class:`IkobaImageFile` you should use
+    :func:`createIkobaImageFile`.
     """
-    implements(IKofaImageFile)
+    implements(IIkobaImageFile)
 
     def __ne__(self, other):
@@ -45,5 +45,5 @@
             return True
 
-def createKofaImageFile(filename, f):
+def createIkobaImageFile(filename, f):
     retrieval = getUtility(IFileRetrieval)
     return retrieval.createFile(filename, f)